==================================
``psyclone.psyad.adjoint_visitor``
==================================

.. automodule:: psyclone.psyad.adjoint_visitor

   .. contents::
      :local:

.. currentmodule:: psyclone.psyad.adjoint_visitor


Classes
=======

- :py:class:`AdjointVisitor`:
  An Adjoint Visitor that translates the PSyIR of a tangent-linear


.. autoclass:: AdjointVisitor
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: AdjointVisitor
      :parts: 1
